mystic.models module documentation
==================================

abstract_model module
---------------------

.. automodule:: mystic.models.abstract_model
..  :exclude-members: +

br8 module
----------

.. automodule:: mystic.models.br8
..  :exclude-members: +

circle module
-------------

.. automodule:: mystic.models.circle
..  :exclude-members: +

dejong module
-------------

.. automodule:: mystic.models.dejong 
..  :exclude-members: +

functions module
----------------

.. automodule:: mystic.models.functions 
..  :exclude-members: +

lorentzian module
-----------------

.. automodule:: mystic.models.lorentzian 
..  :exclude-members: +

mogi module
-----------

.. automodule:: mystic.models.mogi 
..  :exclude-members: +

nag module
----------

.. automodule:: mystic.models.nag 
..  :exclude-members: +

pohlheim module
---------------

.. automodule:: mystic.models.pohlheim 
..  :exclude-members: +

poly module
-----------

.. automodule:: mystic.models.poly 
..  :exclude-members: +

schittkowski module
-------------------

.. automodule:: mystic.models.schittkowski
..  :exclude-members: +

storn module
------------

.. automodule:: mystic.models.storn 
..  :exclude-members: +

venkataraman module
-------------------

.. automodule:: mystic.models.venkataraman 
..  :exclude-members: +

wavy module
-----------

.. automodule:: mystic.models.wavy 
..  :exclude-members: +

wolfram module
--------------

.. automodule:: mystic.models.wolfram 
..  :exclude-members: +
